@@ -126,6 +126,12 @@ coef.tidycrr <- function(object, ...) {
   object$coefs
 }
 
+#' @export
+#' @rdname base_methods_crr
+vcov.tidycrr <- function(object, ...) {
+  object$cmprsk$var
+}
+
 #' @export
 #' @rdname base_methods_crr
 model.matrix.tidycrr <- function(object, ...) {
